==> xlnl-3.3.5.tar.gz: xlnl-3.3.5/src/menu-tab.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: menu-tab.h,v 1.22 2008/01/11 09:12:57 bowkenken Exp $
***************************************************************/

#ifndef	MENU_TAB_H
#define	MENU_TAB_H

/* ˥塼 */

#if	0
char	*menu_kind_ls[] = {
	/* ȥ */
	"<Title>",

	/*  */
	"<Item>",

	/* å */
	"<CheckItem>",

	/*  */
	"<RadioItem>",

	/* ̥ɥ򳫤 */
	"<OpenWinItem>",

	/* <RadioItem>ζڤ */
	"<Separator>",

	/* ˥塼ʣڡͭζڤ */
	"<PageSeparator>",

	/* ֥˥塼 */
	"<Branch>",

	NULL,
};
#endif

#if	0
typedef struct menu_t {
	/* ڹ¤Υѥ */
	char	path[MENU_PATH_MAX_LEN + 1];
	/* ܤμ */
	char	kind[MENU_KIND_MAX_LEN + 1];

	/* ľΥ */
	unsigned char	key;
	/* 硼ȡåȡ */
	char	accel_key[MENU_ACCEL_KEY_MAX_LEN + 1];

	/* ̾ */
	n_msg_t	n_msg;
	char	msg[MENU_MSG_MAX_LEN + 1];

	/* 롦Хåؿ */
	menu_call_back_t	call_back;
	/* 롦Хåؿؤΰ */
	void	*arg;

	/* ե饰 */
	unsigned long	flg;
} menu_t;
#endif

/* ˥塼ꥹ */

menu_t	ls_menu_ask[] = {
	{
		"/ask",
		"<Branch>",
		'\0',
		"",
		N_MSG_NULL, "",
		cb_menu_ask_init, NULL,
		FLG_NULL,
	},
	{
		"/ask/title",
		"<Title>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
	{
		"/ask/yes",
		"<Item>",
		'Y',
		"",
		N_MSG_MENU_YES, "",
		cb_menu_ask_yes, NULL,
		FLG_NULL,
	},
	{
		"/ask/no",
		"<Item>",
		'N',
		"",
		N_MSG_MENU_NO, "",
		cb_menu_ask_no, NULL,
		FLG_NULL,
	},
	{
		"",
		"",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
};

menu_t	ls_menu_func[
	1 + 1 + (5 * FUNC_KEY_MAX)
	+ FUNC_KEY_MAX / MENU_FUNC_MAX_N_PER_PAGE
	+ 1
];

#endif	/* MENU_TAB_H */

==> xlnl-3.4.9.tar.gz: xlnl-3.4.9/src/menu-tab.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: menu-tab.h,v 1.24 2009/06/01 05:05:04 bowkenken Exp $
***************************************************************/

#ifndef	MENU_TAB_H
#define	MENU_TAB_H

/* ˥塼 */

#if	0
char	*menu_kind_ls[] = {
	/* ȥ */
	"<Title>",

	/*  */
	"<Item>",

	/* å */
	"<CheckItem>",

	/*  */
	"<RadioItem>",

	/* ̥ɥ򳫤 */
	"<OpenWinItem>",

	/* <RadioItem>ζڤ */
	"<Separator>",

	/* ˥塼ʣڡͭζڤ */
	"<PageSeparator>",

	/* ֥˥塼 */
	"<Branch>",

	NULL,
};
#endif

#if	0
typedef struct menu_t {
	/* ڹ¤Υѥ */
	char	path[MENU_PATH_MAX_LEN + 1];
	/* ܤμ */
	char	kind[MENU_KIND_MAX_LEN + 1];

	/* ľΥ */
	unsigned char	key;
	/* 硼ȡåȡ */
	char	accel_key[MENU_ACCEL_KEY_MAX_LEN + 1];

	/* ̾ */
	n_msg_t	n_msg;
	char	msg[MENU_MSG_MAX_BYTE + 1];

	/* 롦Хåؿ */
	menu_call_back_t	call_back;
	/* 롦Хåؿؤΰ */
	void	*arg;

	/* ե饰 */
	unsigned long	flg;
} menu_t;
#endif

/* ˥塼ꥹ */

menu_t	ls_menu_ask[] = {
	{
		"/ask",
		"<Branch>",
		'\0',
		"",
		N_MSG_NULL, "",
		cb_menu_ask_init, NULL,
		FLG_NULL,
	},
	{
		"/ask/title",
		"<Title>",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
	{
		"/ask/yes",
		"<Item>",
		'Y',
		"",
		N_MSG_MENU_YES, "",
		cb_menu_ask_yes, NULL,
		FLG_NULL,
	},
	{
		"/ask/no",
		"<Item>",
		'N',
		"",
		N_MSG_MENU_NO, "",
		cb_menu_ask_no, NULL,
		FLG_NULL,
	},
	{
		"",
		"",
		'\0',
		"",
		N_MSG_NULL, "",
		NULL, NULL,
		FLG_NULL,
	},
};

menu_t	ls_menu_func[
	1 + 1 + (5 * FUNC_KEY_MAX)
	+ FUNC_KEY_MAX / MENU_FUNC_MAX_N_PER_PAGE
	+ 1
];

#endif	/* MENU_TAB_H */
